#include "vektor.h"
#include "printer.h"
#include "parser.h"
#include "gfanapplication.h"
#include "minkowskisum.h"
#include "newtonpolytope.h"
#include "buchberger.h"
#include "wallideal.h"
#include "lp.h"
#include "tropical.h"
#include "division.h"
#include "bergman.h"
#include "tropical2.h"
#include "dimension.h"
#include "timer.h"

class TropicalStartingConeApplication : public GFanApplication
{
  FieldOption theFieldOption;
  SimpleOption useThisConeOption;
public:
  bool includeInDefaultInstallation()
  {
    return true;
  }
  const char *helpText()
  {
    return "This program attempts to compute a starting pair of marked reduced Groebner bases to be used as input for gfan_tropicaltraverse. If unsuccessful the program will say so. The input is a homogeneous ideal whose tropical variety is a pure d-dimensional polyhedral complex.\n";
  }
  TropicalStartingConeApplication():
    useThisConeOption("-g","Tell the program that the input is already a reduced Groebner basis.")
  {
    registerOptions();
  }
  char *name()
  {
    return "_tropicalstartingcone";
  }
  int main()
  {
    lpSetSolver("cddgmp");
    FileParser P(Stdin);

    PolynomialSet g=P.parsePolynomialSet();
    if(!useThisConeOption.getValue())
      {
	buchberger(&g,StandardGradedLexicographicTermOrder());
      }
    //    assert(!containsMonomial(g));
    fprintf(Stderr,"Krull dimension of input ideal: %i\n",krullDimension(g));
    fprintf(Stderr,"Dimension of homogeneity space for full ideal: %i\n",dimensionOfHomogeneitySpace(g));
    PolynomialSet fullBasis;
    PolynomialSet g2=guessInitialIdealWithoutMonomial(g,&fullBasis,false); //CHANGETHIS to false
    //    PolynomialSet g2=guessInitialIdealWithoutMonomial(g,&fullBasis,true); //CHANGETHIS to false

    AsciiPrinter(Stdout).printPolynomialSet(g2);
    AsciiPrinter(Stdout).printPolynomialSet(fullBasis);

    fprintf(Stderr,"Krull dimension of input ideal: %i\n",krullDimension(g));
    fprintf(Stderr,"Dimension of homogeneity space for full ideal: %i\n",dimensionOfHomogeneitySpace(g));
    fprintf(Stderr,"Dimension of homogeneity space for initial ideal: %i\n",dimensionOfHomogeneitySpace(g2));

    return 0;
  }
};

static TropicalStartingConeApplication theApplication;
